@@ -81,24 +81,6 @@ MIGRATE = {
 
 
 SYNC = {
-    "createTime": {"require": True, "type": str, "default": "2022-10-06T18:43:04.352+00:00"},
-    "showInspectTips": {"type": bool, "require": True, "default": False},
-    "planStartDateFlag": {"type": bool, "require": True, "default": False, "desc": "plan start date or not"},
-    "canOpenInspect": {"type": bool, "require": True, "default": True},
-    "isOpenAutoDDL": {"type": bool, "require": True, "default": False},
-    "isSchedule": {"type": bool, "require": True, "default": False},
-    "isStopOnError": {"type": bool, "require": True, "default": True},
-    "readBatchSize": {"type": int, "require": True, "default": 500},
-    "shareCache": {"type": bool, "require": True, "default": False},
-    "writeThreadSize": {"type": int, "require": True, "default": 8},
-    "isFilter": {"type": bool, "require": True, "default": False},
-    "isAutoInspect": {"type": bool, "require": True, "default": False},
-    "increaseSyncInterval": {"type": int, "require": True, "default": 500},
-    "autoInspect": {"type": bool, "require": True, "default": False},
-    "accessNodeProcessId": {"type": str, "require": True, "default": ""},
-    "accessNodeProcessIdList": {"type": list, "require": True, "default": []},
-    "increShareReadMode": {"type": str, "require": True, "default": "STREAMING"},
-    "accessNodeType": {"type": str, "require": True, "default": "AUTOMATIC_PLATFORM_ALLOCATION"},
     "syncType": {"type": str, "require": True, "reg": r"sync", "default": "sync"},
     "type": {"type": str, "require": True, "option": ["initial_sync", "cdc", "initial_sync+cdc"], "default": "initial_sync+cdc"},
     "desc": {"type": str, "require": True, "default": "", "desc": "describe a job or pipeline."},
@@ -109,7 +91,7 @@ SYNC = {
     "hysteresisInterval": {"type": int, "require": False},
     "increaseReadSize": {"type": int, "require": True, "default": 500},
     "increOperationMode": {"type": bool, "require": True, "default": False},
-    "processorThreadNum": {"type": int, "require": True, "default": 1},
+    "processorThreadNum": {"type": int, "require": True, "default": 8},
     "shareCdcEnable": {"type": bool, "require": True, "default": False},
     "syncPoints": {"type": list, "require": False, "value": {
         "connectionId": {"require": True, "type": str},
@@ -120,25 +102,6 @@ SYNC = {
     "crontabExpression": {"type": str, "require": False,
         "desc": "repeat call task, Example: 0 */1 * * * ? * // Run every minute 0 0 2 * * ? * // Run at 2 every day",
     },
-    "btnDisabled": {"type": dict, "require": True, "value": {
-        "delete": {"require": True, "type": bool, "default": False},
-        "edit": {"require": True, "type": bool, "default": False},
-        "forceStop": {"require": True, "type": bool, "default": True},
-        "monitor": {"require": True, "type": bool, "default": True},
-        "reset": {"require": True, "type": bool, "default": True},
-        "start": {"require": True, "type": bool, "default": False},
-        "stop": {"require": True, "type": bool, "default": True},
-    }},
-    "disabledData": {"type": dict, "require": True, "value": {
-        "delete": {"require": True, "type": bool, "default": False},
-        "edit": {"require": True, "type": bool, "default": False},
-        "forceStop": {"require": True, "type": bool, "default": True},
-        "monitor": {"require": True, "type": bool, "default": True},
-        "reset": {"require": True, "type": bool, "default": True},
-        "start": {"require": True, "type": bool, "default": False},
-        "stop": {"require": True, "type": bool, "default": True},
-    }},
-    "_deleted": {"type": bool, "require": True, "default": False},
 }
 
 
